@@ -15,13 +15,11 @@ memory_released <- function(og, butchered) {
   old <- lobstr::obj_size(og)
   new <- lobstr::obj_size(butchered)
   rel <- old - new
-  rel <- format(rel, big.mark = ",", scientific = FALSE)
   if (length(rel) == 1) {
-    if (rel <= 0) {
+    if (isTRUE(all.equal(old, new))) {
       return(NULL)
-    } else {
-      return(rel)
     }
+    return(rel)
   } else {
     return(NULL)
   }
@@ -35,13 +33,18 @@ assess_object <- function(og, butchered) {
   if (is.null(mem)) {
     cli::cli_alert_danger("No memory released. Do not butcher.")
   } else {
-    cli::cli_alert_success("Memory released: {.val {mem}}")
-    if (!is.null(disabled)) {
-      cli::cli_alert_danger("Disabled: {.code {disabled}}")
-    }
-    if (length(class_added) == 0) {
-      class_name <- "butchered"
-      cli::cli_alert_danger("Could not add {.cls {class_name}} class")
+    abs_mem <- format(abs(mem), big.mark = ",", scientific = FALSE)
+    if (mem < 0) {
+      cli::cli_alert_danger("The butchered object is {.field {abs_mem}} larger than the original. Do not butcher.")
+    } else {
+      cli::cli_alert_success("Memory released: {.field {abs_mem}}")
+      if (!is.null(disabled)) {
+        cli::cli_alert_danger("Disabled: {.code {disabled}}")
+      }
+      if (length(class_added) == 0) {
+        class_name <- "butchered"
+        cli::cli_alert_danger("Could not add {.cls {class_name}} class")
+      }
     }
   }
 }
