@@ -1,20 +1,18 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
-  eval = requireNamespace("dplyr", quietly = TRUE) & 
-         requireNamespace("clisymbols", quietly = TRUE)
+  eval = requireNamespace("dplyr", quietly = TRUE)
 )
 
 ## ----setup, echo = FALSE, warnings = FALSE, message = FALSE-------------------
 suppressWarnings(library(butcher))
 suppressWarnings(library(dplyr))
-suppressWarnings(library(clisymbols))
 
 method_df <- function(method_name) {
   m <- as.vector(utils::methods(method_name))
   tibble::tibble(class = gsub(paste0(method_name, "[.]"), "", m),
-                 !!method_name := clisymbols::symbol$tick)
+                 !!method_name := cli::symbol$tick)
 }
 
 replace_na <- function(x) {
