@@ -1,5 +1,3 @@
-context("train.recipe")
-
 # Train objects are large so create on the fly
 # test_that("train + butcher_example() works", {
 #   example_files <- butcher_example()
@@ -12,9 +10,9 @@ test_that("train + predict() works", {
   skip_if_not_installed("caret")
   skip_if_not_installed("recipes")
   # Load
-  library(recipes)
-  library(caret)
-  library(modeldata)
+  suppressPackageStartupMessages(library(recipes))
+  suppressPackageStartupMessages(library(caret))
+  suppressPackageStartupMessages(library(modeldata))
   # Data
   data(biomass)
   biomass_tr <- biomass[biomass$dataset == "Training",]
